from typing import Optional, List
from datetime import datetime
from pydantic import EmailStr, Field, TypeAdapter

from api.db.tables.account import AccountRole, AccountStatus

from api.schemas.base import Base


class UserUpdate(Base):
    id: Optional[int] = None
    name: Optional[str] = Field(None, max_length=100)
    login: Optional[str] = Field(None, max_length=100)
    email: Optional[EmailStr] = None
    bind_tenant_id: Optional[str] = Field(None, max_length=40)
    role: Optional[AccountRole] = None
    meta: Optional[dict] = None
    creator_id: Optional[int] = None
    created_at: Optional[datetime] = None
    status: Optional[AccountStatus] = None


class AllUser(Base):
    id: int
    name: str
    login: str
    email: Optional[EmailStr] = None
    bind_tenant_id: Optional[str] = None
    role: AccountRole
    created_at: datetime
    status: AccountStatus


class AllUserResponse(Base):
    users: List[AllUser]
    amount_count: int
    amount_pages: int


all_user_adapter = TypeAdapter(List[AllUser])
