from fastapi import Request, HTTPException
from typing import Optional
from sqlalchemy.ext.asyncio import AsyncConnection
from api.db.logic.auth import get_user

# # from backend.schemas.users.token import TokenData
from api.schemas.account.account import User
from api.db.tables.account import AccountStatus

from api.utils.hasher import Hasher


async def get_current_user(request: Request) -> Optional[User]:
    if not hasattr(request.state, "current_user"):
        return HTTPException(status_code=401, detail="Unauthorized")
    return request.state.current_user


async def authenticate_user(connection: AsyncConnection, username: str, password: str) -> Optional[User]:
    sql_user, sql_password = await get_user(connection, username)

    if not sql_user or sql_user.status != AccountStatus.ACTIVE:
        return None
    hasher = Hasher()
    if not hasher.verify_data(password, sql_password.key_value):
        return None
    return sql_user
